;; Generated package description from windower.el  -*- no-byte-compile: t -*-
(define-package "windower" "0.0.1.0.20200212.91532" "Helper functions for window manipulation." '((emacs "25")) :commit "63b94d6436c2f7ef8018783a10a3579010154022" :authors '(("Pierre Neidhardt" . "mail@ambrevar.xyz")) :maintainer '("Pierre Neidhardt" . "mail@ambrevar.xyz") :keywords '("convenience" "tools") :url "https://gitlab.com/ambrevar/windower")
